# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_volatility.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/intraday_analytics/v1/intraday_volatility.proto',
  package='systemathics.apis.services.intraday_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nJsystemathics/apis/services/intraday_analytics/v1/intraday_volatility.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xf3\x01\n\x19IntradayVolatilityRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"+\n\x1aIntradayVolatilityResponse\x12\r\n\x05value\x18\x01 \x01(\x01\x32\xcd\x01\n\x19IntradayVolatilityService\x12\xaf\x01\n\x12IntradayVolatility\x12K.systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest\x1aL.systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponseb\x06proto3'
  ,
  dependencies=[systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2.DESCRIPTOR,])




_INTRADAYVOLATILITYREQUEST = _descriptor.Descriptor(
  name='IntradayVolatilityRequest',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest.sampling', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest.constraints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest.adjustment', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=524,
)


_INTRADAYVOLATILITYRESPONSE = _descriptor.Descriptor(
  name='IntradayVolatilityResponse',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponse.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=569,
)

_INTRADAYVOLATILITYREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_INTRADAYVOLATILITYREQUEST.fields_by_name['sampling'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2._SAMPLING
_INTRADAYVOLATILITYREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
DESCRIPTOR.message_types_by_name['IntradayVolatilityRequest'] = _INTRADAYVOLATILITYREQUEST
DESCRIPTOR.message_types_by_name['IntradayVolatilityResponse'] = _INTRADAYVOLATILITYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IntradayVolatilityRequest = _reflection.GeneratedProtocolMessageType('IntradayVolatilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVOLATILITYREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest)
  })
_sym_db.RegisterMessage(IntradayVolatilityRequest)

IntradayVolatilityResponse = _reflection.GeneratedProtocolMessageType('IntradayVolatilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVOLATILITYRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponse)
  })
_sym_db.RegisterMessage(IntradayVolatilityResponse)



_INTRADAYVOLATILITYSERVICE = _descriptor.ServiceDescriptor(
  name='IntradayVolatilityService',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=572,
  serialized_end=777,
  methods=[
  _descriptor.MethodDescriptor(
    name='IntradayVolatility',
    full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityService.IntradayVolatility',
    index=0,
    containing_service=None,
    input_type=_INTRADAYVOLATILITYREQUEST,
    output_type=_INTRADAYVOLATILITYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INTRADAYVOLATILITYSERVICE)

DESCRIPTOR.services_by_name['IntradayVolatilityService'] = _INTRADAYVOLATILITYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/sampling.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/sampling.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/systemathics/apis/type/shared/v1/sampling.proto\x12 systemathics.apis.type.shared.v1*\xa6\x01\n\x08Sampling\x12\x17\n\x13SAMPLING_ONE_MINUTE\x10\x00\x12\x18\n\x14SAMPLING_FIVE_MINUTE\x10\x01\x12\x17\n\x13SAMPLING_TEN_MINUTE\x10\x02\x12\x1b\n\x17SAMPLING_FIFTEEN_MINUTE\x10\x03\x12\x1a\n\x16SAMPLING_THIRTY_MINUTE\x10\x04\x12\x15\n\x11SAMPLING_ONE_HOUR\x10\x05\x62\x06proto3'
)

_SAMPLING = _descriptor.EnumDescriptor(
  name='Sampling',
  full_name='systemathics.apis.type.shared.v1.Sampling',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SAMPLING_ONE_MINUTE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAMPLING_FIVE_MINUTE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAMPLING_TEN_MINUTE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAMPLING_FIFTEEN_MINUTE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAMPLING_THIRTY_MINUTE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAMPLING_ONE_HOUR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=86,
  serialized_end=252,
)
_sym_db.RegisterEnumDescriptor(_SAMPLING)

Sampling = enum_type_wrapper.EnumTypeWrapper(_SAMPLING)
SAMPLING_ONE_MINUTE = 0
SAMPLING_FIVE_MINUTE = 1
SAMPLING_TEN_MINUTE = 2
SAMPLING_FIFTEEN_MINUTE = 3
SAMPLING_THIRTY_MINUTE = 4
SAMPLING_ONE_HOUR = 5


DESCRIPTOR.enum_types_by_name['Sampling'] = _SAMPLING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_macd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/intraday_analytics/v1/intraday_macd.proto',
  package='systemathics.apis.services.intraday_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nDsystemathics/apis/services/intraday_analytics/v1/intraday_macd.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\x8a\x02\n\x13IntradayMacdRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0c\n\x04long\x18\x04 \x01(\x05\x12\r\n\x05short\x18\x05 \x01(\x05\x12\x12\n\nadjustment\x18\x06 \x01(\x08\"h\n\x14IntradayMacdResponse\x12P\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x42.systemathics.apis.services.intraday_analytics.v1.IntradayMacdData\"|\n\x10IntradayMacdData\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0c\n\x04macd\x18\x03 \x01(\x01\x12\r\n\x05short\x18\x04 \x01(\x01\x12\x0c\n\x04long\x18\x05 \x01(\x01\x32\xb5\x01\n\x13IntradayMacdService\x12\x9d\x01\n\x0cIntradayMacd\x12\x45.systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest\x1a\x46.systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2.DESCRIPTOR,])




_INTRADAYMACDREQUEST = _descriptor.Descriptor(
  name='IntradayMacdRequest',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.sampling', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.constraints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.long', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.short', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.adjustment', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=574,
)


_INTRADAYMACDRESPONSE = _descriptor.Descriptor(
  name='IntradayMacdResponse',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=680,
)


_INTRADAYMACDDATA = _descriptor.Descriptor(
  name='IntradayMacdData',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='macd', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData.macd', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData.short', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData.long', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=806,
)

_INTRADAYMACDREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_INTRADAYMACDREQUEST.fields_by_name['sampling'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2._SAMPLING
_INTRADAYMACDREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_INTRADAYMACDRESPONSE.fields_by_name['data'].message_type = _INTRADAYMACDDATA
_INTRADAYMACDDATA.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['IntradayMacdRequest'] = _INTRADAYMACDREQUEST
DESCRIPTOR.message_types_by_name['IntradayMacdResponse'] = _INTRADAYMACDRESPONSE
DESCRIPTOR.message_types_by_name['IntradayMacdData'] = _INTRADAYMACDDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IntradayMacdRequest = _reflection.GeneratedProtocolMessageType('IntradayMacdRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest)
  })
_sym_db.RegisterMessage(IntradayMacdRequest)

IntradayMacdResponse = _reflection.GeneratedProtocolMessageType('IntradayMacdResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponse)
  })
_sym_db.RegisterMessage(IntradayMacdResponse)

IntradayMacdData = _reflection.GeneratedProtocolMessageType('IntradayMacdData', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDDATA,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdData)
  })
_sym_db.RegisterMessage(IntradayMacdData)



_INTRADAYMACDSERVICE = _descriptor.ServiceDescriptor(
  name='IntradayMacdService',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=809,
  serialized_end=990,
  methods=[
  _descriptor.MethodDescriptor(
    name='IntradayMacd',
    full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdService.IntradayMacd',
    index=0,
    containing_service=None,
    input_type=_INTRADAYMACDREQUEST,
    output_type=_INTRADAYMACDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INTRADAYMACDSERVICE)

DESCRIPTOR.services_by_name['IntradayMacdService'] = _INTRADAYMACDSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/sustainability/v1/sustainability.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/sustainability/v1/sustainability.proto',
  package='systemathics.apis.services.sustainability.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAsystemathics/apis/services/sustainability/v1/sustainability.proto\x12,systemathics.apis.services.sustainability.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"Y\n\x15SustainabilityRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\"d\n\x16SustainabilityResponse\x12J\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32<.systemathics.apis.services.sustainability.v1.Sustainability\"\x8a\x01\n\x0eSustainability\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\x12\x0b\n\x03min\x18\x06 \x01(\x01\x12\x0b\n\x03max\x18\x07 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t2\xb5\x01\n\x15SustainabilityService\x12\x9b\x01\n\x0eSustainability\x12\x43.systemathics.apis.services.sustainability.v1.SustainabilityRequest\x1a\x44.systemathics.apis.services.sustainability.v1.SustainabilityResponseb\x06proto3'
  ,
  dependencies=[systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])




_SUSTAINABILITYREQUEST = _descriptor.Descriptor(
  name='SustainabilityRequest',
  full_name='systemathics.apis.services.sustainability.v1.SustainabilityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.sustainability.v1.SustainabilityRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=255,
)


_SUSTAINABILITYRESPONSE = _descriptor.Descriptor(
  name='SustainabilityResponse',
  full_name='systemathics.apis.services.sustainability.v1.SustainabilityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.sustainability.v1.SustainabilityResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=357,
)


_SUSTAINABILITY = _descriptor.Descriptor(
  name='Sustainability',
  full_name='systemathics.apis.services.sustainability.v1.Sustainability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider', full_name='systemathics.apis.services.sustainability.v1.Sustainability.provider', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.sustainability.v1.Sustainability.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='systemathics.apis.services.sustainability.v1.Sustainability.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='systemathics.apis.services.sustainability.v1.Sustainability.parent', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.sustainability.v1.Sustainability.value', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='systemathics.apis.services.sustainability.v1.Sustainability.min', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='systemathics.apis.services.sustainability.v1.Sustainability.max', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='systemathics.apis.services.sustainability.v1.Sustainability.description', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=498,
)

_SUSTAINABILITYREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_SUSTAINABILITYRESPONSE.fields_by_name['data'].message_type = _SUSTAINABILITY
DESCRIPTOR.message_types_by_name['SustainabilityRequest'] = _SUSTAINABILITYREQUEST
DESCRIPTOR.message_types_by_name['SustainabilityResponse'] = _SUSTAINABILITYRESPONSE
DESCRIPTOR.message_types_by_name['Sustainability'] = _SUSTAINABILITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SustainabilityRequest = _reflection.GeneratedProtocolMessageType('SustainabilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITYREQUEST,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.SustainabilityRequest)
  })
_sym_db.RegisterMessage(SustainabilityRequest)

SustainabilityResponse = _reflection.GeneratedProtocolMessageType('SustainabilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITYRESPONSE,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.SustainabilityResponse)
  })
_sym_db.RegisterMessage(SustainabilityResponse)

Sustainability = _reflection.GeneratedProtocolMessageType('Sustainability', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITY,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.Sustainability)
  })
_sym_db.RegisterMessage(Sustainability)



_SUSTAINABILITYSERVICE = _descriptor.ServiceDescriptor(
  name='SustainabilityService',
  full_name='systemathics.apis.services.sustainability.v1.SustainabilityService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=501,
  serialized_end=682,
  methods=[
  _descriptor.MethodDescriptor(
    name='Sustainability',
    full_name='systemathics.apis.services.sustainability.v1.SustainabilityService.Sustainability',
    index=0,
    containing_service=None,
    input_type=_SUSTAINABILITYREQUEST,
    output_type=_SUSTAINABILITYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SUSTAINABILITYSERVICE)

DESCRIPTOR.services_by_name['SustainabilityService'] = _SUSTAINABILITYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v1/intraday_vwap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/intraday/v1/intraday_vwap.proto',
  package='systemathics.apis.services.intraday.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:systemathics/apis/services/intraday/v1/intraday_vwap.proto\x12&systemathics.apis.services.intraday.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xee\x01\n\x14IntradayVwapsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"[\n\x15IntradayVwapsResponse\x12\x42\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.services.intraday.v1.IntradayVwap\"l\n\x0cIntradayVwap\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\r\n\x05score\x18\x04 \x01(\x01\x32\xa5\x01\n\x14IntradayVwapsService\x12\x8c\x01\n\rIntradayVwaps\x12<.systemathics.apis.services.intraday.v1.IntradayVwapsRequest\x1a=.systemathics.apis.services.intraday.v1.IntradayVwapsResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2.DESCRIPTOR,])




_INTRADAYVWAPSREQUEST = _descriptor.Descriptor(
  name='IntradayVwapsRequest',
  full_name='systemathics.apis.services.intraday.v1.IntradayVwapsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.intraday.v1.IntradayVwapsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='systemathics.apis.services.intraday.v1.IntradayVwapsRequest.sampling', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.intraday.v1.IntradayVwapsRequest.constraints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.intraday.v1.IntradayVwapsRequest.adjustment', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=526,
)


_INTRADAYVWAPSRESPONSE = _descriptor.Descriptor(
  name='IntradayVwapsResponse',
  full_name='systemathics.apis.services.intraday.v1.IntradayVwapsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.intraday.v1.IntradayVwapsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=619,
)


_INTRADAYVWAP = _descriptor.Descriptor(
  name='IntradayVwap',
  full_name='systemathics.apis.services.intraday.v1.IntradayVwap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.intraday.v1.IntradayVwap.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='systemathics.apis.services.intraday.v1.IntradayVwap.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='systemathics.apis.services.intraday.v1.IntradayVwap.volume', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='systemathics.apis.services.intraday.v1.IntradayVwap.score', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=729,
)

_INTRADAYVWAPSREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_INTRADAYVWAPSREQUEST.fields_by_name['sampling'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2._SAMPLING
_INTRADAYVWAPSREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_INTRADAYVWAPSRESPONSE.fields_by_name['data'].message_type = _INTRADAYVWAP
_INTRADAYVWAP.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['IntradayVwapsRequest'] = _INTRADAYVWAPSREQUEST
DESCRIPTOR.message_types_by_name['IntradayVwapsResponse'] = _INTRADAYVWAPSRESPONSE
DESCRIPTOR.message_types_by_name['IntradayVwap'] = _INTRADAYVWAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IntradayVwapsRequest = _reflection.GeneratedProtocolMessageType('IntradayVwapsRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVWAPSREQUEST,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayVwapsRequest)
  })
_sym_db.RegisterMessage(IntradayVwapsRequest)

IntradayVwapsResponse = _reflection.GeneratedProtocolMessageType('IntradayVwapsResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVWAPSRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayVwapsResponse)
  })
_sym_db.RegisterMessage(IntradayVwapsResponse)

IntradayVwap = _reflection.GeneratedProtocolMessageType('IntradayVwap', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVWAP,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayVwap)
  })
_sym_db.RegisterMessage(IntradayVwap)



_INTRADAYVWAPSSERVICE = _descriptor.ServiceDescriptor(
  name='IntradayVwapsService',
  full_name='systemathics.apis.services.intraday.v1.IntradayVwapsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=732,
  serialized_end=897,
  methods=[
  _descriptor.MethodDescriptor(
    name='IntradayVwaps',
    full_name='systemathics.apis.services.intraday.v1.IntradayVwapsService.IntradayVwaps',
    index=0,
    containing_service=None,
    input_type=_INTRADAYVWAPSREQUEST,
    output_type=_INTRADAYVWAPSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INTRADAYVWAPSSERVICE)

DESCRIPTOR.services_by_name['IntradayVwapsService'] = _INTRADAYVWAPSSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v1/intraday_bars.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/intraday/v1/intraday_bars.proto',
  package='systemathics.apis.services.intraday.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:systemathics/apis/services/intraday/v1/intraday_bars.proto\x12&systemathics.apis.services.intraday.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xed\x01\n\x13IntradayBarsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"Y\n\x14IntradayBarsResponse\x12\x41\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x33.systemathics.apis.services.intraday.v1.IntradayBar\"\xb1\x01\n\x0bIntradayBar\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04open\x18\x02 \x01(\x01\x12\x0c\n\x04high\x18\x03 \x01(\x01\x12\x0b\n\x03low\x18\x04 \x01(\x01\x12\r\n\x05\x63lose\x18\x05 \x01(\x01\x12\x0e\n\x06volume\x18\x06 \x01(\x03\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x0c\n\x04vwap\x18\x08 \x01(\x01\x12\r\n\x05score\x18\t \x01(\x01\x32\xa1\x01\n\x13IntradayBarsService\x12\x89\x01\n\x0cIntradayBars\x12;.systemathics.apis.services.intraday.v1.IntradayBarsRequest\x1a<.systemathics.apis.services.intraday.v1.IntradayBarsResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2.DESCRIPTOR,])




_INTRADAYBARSREQUEST = _descriptor.Descriptor(
  name='IntradayBarsRequest',
  full_name='systemathics.apis.services.intraday.v1.IntradayBarsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.intraday.v1.IntradayBarsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='systemathics.apis.services.intraday.v1.IntradayBarsRequest.sampling', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.intraday.v1.IntradayBarsRequest.constraints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.intraday.v1.IntradayBarsRequest.adjustment', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=525,
)


_INTRADAYBARSRESPONSE = _descriptor.Descriptor(
  name='IntradayBarsResponse',
  full_name='systemathics.apis.services.intraday.v1.IntradayBarsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.intraday.v1.IntradayBarsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=616,
)


_INTRADAYBAR = _descriptor.Descriptor(
  name='IntradayBar',
  full_name='systemathics.apis.services.intraday.v1.IntradayBar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.intraday.v1.IntradayBar.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='systemathics.apis.services.intraday.v1.IntradayBar.open', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='systemathics.apis.services.intraday.v1.IntradayBar.high', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='systemathics.apis.services.intraday.v1.IntradayBar.low', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='systemathics.apis.services.intraday.v1.IntradayBar.close', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='systemathics.apis.services.intraday.v1.IntradayBar.volume', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='systemathics.apis.services.intraday.v1.IntradayBar.count', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vwap', full_name='systemathics.apis.services.intraday.v1.IntradayBar.vwap', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='systemathics.apis.services.intraday.v1.IntradayBar.score', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=619,
  serialized_end=796,
)

_INTRADAYBARSREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_INTRADAYBARSREQUEST.fields_by_name['sampling'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2._SAMPLING
_INTRADAYBARSREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_INTRADAYBARSRESPONSE.fields_by_name['data'].message_type = _INTRADAYBAR
_INTRADAYBAR.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['IntradayBarsRequest'] = _INTRADAYBARSREQUEST
DESCRIPTOR.message_types_by_name['IntradayBarsResponse'] = _INTRADAYBARSRESPONSE
DESCRIPTOR.message_types_by_name['IntradayBar'] = _INTRADAYBAR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IntradayBarsRequest = _reflection.GeneratedProtocolMessageType('IntradayBarsRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYBARSREQUEST,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayBarsRequest)
  })
_sym_db.RegisterMessage(IntradayBarsRequest)

IntradayBarsResponse = _reflection.GeneratedProtocolMessageType('IntradayBarsResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYBARSRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayBarsResponse)
  })
_sym_db.RegisterMessage(IntradayBarsResponse)

IntradayBar = _reflection.GeneratedProtocolMessageType('IntradayBar', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYBAR,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayBar)
  })
_sym_db.RegisterMessage(IntradayBar)



_INTRADAYBARSSERVICE = _descriptor.ServiceDescriptor(
  name='IntradayBarsService',
  full_name='systemathics.apis.services.intraday.v1.IntradayBarsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=799,
  serialized_end=960,
  methods=[
  _descriptor.MethodDescriptor(
    name='IntradayBars',
    full_name='systemathics.apis.services.intraday.v1.IntradayBarsService.IntradayBars',
    index=0,
    containing_service=None,
    input_type=_INTRADAYBARSREQUEST,
    output_type=_INTRADAYBARSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INTRADAYBARSSERVICE)

DESCRIPTOR.services_by_name['IntradayBarsService'] = _INTRADAYBARSSERVICE

# @@protoc_insertion_point(module_scope)
